@@ -1,3 +1,3 @@
-from .database import *
+from .db import *
+from .multiprogramming import *
 from .repl import *
-from .multiprogramming import *
\ No newline at end of file
