@@ -1,6 +1,9 @@
 """Comparer class"""
+import logging
 from typing import Callable,  Union, Generic, TypeVar
+from ..logging_.utils import get_logger
 from .functions import default_weight_function
+logger = get_logger(__name__)
 
 U = TypeVar("U")
 V = TypeVar("V")
@@ -12,6 +15,7 @@ class Comparer(Generic[U, V]):
 
     def __init__(self, func: Callable[[U, V], Union[int, float]]):
         self.func = func
+        logger.debug("Comparer initialized with function: %s", func.__name__)
 
     def compare(self, v1: U, v2: V) -> Union[int, float]:
         """compares two objects
@@ -23,7 +27,10 @@ class Comparer(Generic[U, V]):
             Returns:
                 int: a number specifying the order of the objects
             """
-        return self.func(v1, v2)
+        logger.debug("Comparing objects: %s vs %s", v1, v2)
+        result = self.func(v1, v2)
+        logger.debug("Comparison result: %s", result)
+        return result
 
     def __call__(self, v1: U, v2: V) -> Union[int, float]:
         return self.compare(v1, v2)
