@@ -1,5 +1,7 @@
+import logging
 from typing import Optional, Generator, List as List, Set as Set, Dict as Dict, Generic, \
     TypeVar, Iterable, Iterator
+from ...logging_.utils import get_logger
 from ..queue import Queue
 from .multinode import MultiNode
 from ...reflection import get_python_version
@@ -9,6 +11,8 @@ if get_python_version() >= (3, 9):
 
 T = TypeVar("T")
 
+logger = get_logger(__name__)
+
 
 class Graph(Generic[T]):
     """A general-purpose Graph class.
@@ -36,12 +40,14 @@ class Graph(Generic[T]):
         Returns:
             dict: A dictionary representing the graph.
         """
+        logger.debug("Converting graph with %s nodes to dictionary", len(self.nodes))
         dct: Dict[T, Set[T]] = {}
         for node in self:
             v = dct.get(node.data, set())
             for child in node:
                 v.add(child.data)
             dct[node.data] = v
+        logger.debug("Graph converted to dictionary with %s entries", len(dct))
         return dct
 
     @staticmethod
@@ -54,6 +60,7 @@ class Graph(Generic[T]):
         Returns:
             Graph[T]: A graph representing the given dictionary.
         """
+        logger.debug("Creating graph from dictionary with %s entries", len(dct))
         g: Graph[T] = Graph()
         seen: Dict[T, MultiNode[T]] = {}
         for k, v in dct.items():
@@ -64,10 +71,12 @@ class Graph(Generic[T]):
                 seen[k].add_child(seen[o])
 
             g.add_node(seen[k])
+        logger.info("Graph created from dictionary with %s nodes", len(g.nodes))
         return g
 
     def __init__(self, nodes: Optional[List[MultiNode[T]]] = None):
         self.nodes: List[MultiNode[T]] = nodes if nodes is not None else []
+        logger.debug("Graph initialized with %s nodes", len(self.nodes))
 
     def add_node(self, node: MultiNode[T]) -> None:
         """Add a node to the graph.
@@ -76,6 +85,7 @@ class Graph(Generic[T]):
             node: The MultiNode instance to add to the graph.
         """
         self.nodes.append(node)
+        logger.debug("Added node to graph, total nodes: %s", len(self.nodes))
 
     def _extended_dfs(self) -> Generator[MultiNode[T], None, List[MultiNode[T]]]:
         """Perform an extended depth-first search on the graph.
@@ -141,6 +151,7 @@ class Graph(Generic[T]):
         Yields:
             Generator: The MultiNode instances in the order of depth-first traversal.
         """
+        logger.debug("Starting DFS traversal on graph with %s nodes", len(self.nodes))
         yield from self._extended_dfs()
 
     def topological_sort(self) -> List[MultiNode[T]]:
@@ -151,12 +162,15 @@ class Graph(Generic[T]):
         Returns:
             list: A list containing the MultiNode instances in topological order.
         """
+        logger.debug("Starting topological sort on graph with %s nodes", len(self.nodes))
         g = self._extended_dfs()
         try:
             while True:
                 next(g)
         except StopIteration as e:
-            return e.value
+            result = e.value
+            logger.info("Topological sort completed, result has %s nodes", len(result))
+            return result
 
     def bfs(self) -> Generator[MultiNode[T], None, None]:
         """Perform a breadth-first search on the graph.
@@ -166,6 +180,7 @@ class Graph(Generic[T]):
         Yields:
             Generator: The MultiNode instances in the order of breadth-first traversal.
         """
+        logger.debug("Starting BFS traversal on graph with %s nodes", len(self.nodes))
         q: Queue[MultiNode[T]] = Queue()
         for node in self.nodes:
             q.push(node)
@@ -176,6 +191,7 @@ class Graph(Generic[T]):
                 yield node
                 for child in node._children:  # pylint: disable=protected-access
                     q.push(child)  # type:ignore
+        logger.debug("BFS traversal completed, visited %s nodes", len(seen))
 
     def __str__(self) -> str:
         tmp = []
