@@ -1,12 +1,16 @@
 import inspect
+import logging
 from typing import Optional, Callable
 from ..interpreter import get_python_version, get_prev_frame
+from ...logging_.utils import get_logger
 
 if get_python_version() < (3, 9):
     from typing import Set as Set  # pylint: disable=ungrouped-imports
 else:
     from builtins import set as Set
 
+logger = get_logger(__name__)
+
 
 def get_caller_name(steps_back: int) -> Optional[str]:
     """returns the name caller of the function
@@ -17,17 +21,21 @@ def get_caller_name(steps_back: int) -> Optional[str]:
     USING THIS FUNCTION WHILE DEBUGGING WILL ADD ADDITIONAL FRAMES TO THE TRACEBACK
     """
     if not isinstance(steps_back, int):
+        logger.error("Invalid steps_back type: %s", type(steps_back))
         raise TypeError("steps_back must be an int")
     if steps_back < 0:
+        logger.error("Invalid steps_back value: %s", steps_back)
         raise ValueError("steps_back must be a non-negative integer")
     if (frame := get_prev_frame(2 + steps_back)) is None:
         return None
-    return frame.f_code.co_name
+    caller_name = frame.f_code.co_name
+    return caller_name
 
 
 def get_prev_func(steps_back: int) -> Optional[Callable]:
     """Returns the current function"""
     if steps_back < 0:
+        logger.error("Invalid steps_back value: %s", steps_back)
         raise ValueError("n_step must be a non-negative integer")
     if (caller_frame := get_prev_frame(2 + steps_back)) is None:
         return None
@@ -99,11 +107,13 @@ def is_function_annotated_properly(func: Callable, ignore: Optional[set] = None,
     """
     from ...functions.isoftype import isoftype
     if not inspect.isfunction(func):
+        logger.error("Invalid function type: %s", type(func))
         raise ValueError("param should be a function")
 
     if ignore is None:
         ignore = {"self", "cls", "args", "kwargs"}
     if not isoftype(ignore, Set[str]):
+        logger.error("Invalid ignore type: %s", type(ignore))
         raise ValueError("ignore must be a set of str")
 
     # get the signature of the function
@@ -124,8 +134,6 @@ def is_function_annotated_properly(func: Callable, ignore: Optional[set] = None,
             if not isoftype(default_value, arg_type):
                 return False
 
-    if check_return:
-        pass
     return True
 
 
