@@ -1,6 +1,6 @@
 from .argument_info import *
 from .class_info import *
-from .decoration_info import *
+from .decorator_info import *
 from .file_info import *
 from .function_info import *
 from .import_info import *
