@@ -1,4 +1,8 @@
+import logging
 from ..backoff_strategy import BackOffStrategy
+from ...logging_.utils import get_logger
+
+logger = get_logger(__name__)
 
 
 class ConstantBackOffStrategy(BackOffStrategy):
@@ -10,6 +14,7 @@ class ConstantBackOffStrategy(BackOffStrategy):
 
     def __init__(self, delay: float) -> None:
         if not delay >= 0:
+            logger.error("Invalid delay value: %s - must be positive", delay)
             raise ValueError("delay must be positive")
         delay = float(delay)
         super().__init__(lambda: delay)
